procedure TileSet.LoadFromImage(Dat: Image);
begin
	Data := Dat;
end;

procedure TileSet.SetTileTable(X,Y: Int64);
begin
	TilesPerRow := X;
	TilesPerColumn := Y;
end;

procedure TileSet.SetTiles(Val: Int64);
begin
	Tiles := Val;
end;

procedure TileSet.LoadFromImageFile(Src: String);
begin
	Data.Load(Src);
end;

procedure TileSet.LoadFromDisk(Src: String);
var
	Disk: Text;
	RAM: String;
	Position: Int64;
	
begin
	Assign(Disk, Src);
	Reset(Disk);
	
	readln(Disk, RAM);
	Data.Load(RAM);
	
	//Read the OffSetX and OffSetY values
	readln(Disk, RAM);
	Position := 0;
	repeat
		Position := Position + 1;
		until (RAM[Position] = ';') or (RAM[Position] = '.') or (RAM[Position] = ',') or (Position > Length(RAM));
		
	OffSetX := StrToInt(RAM[1..Position - 1]);
	OffSetY := StrToInt(RAM[Position + 1.. Length(RAM)]);
	
	//Read the SpacingX and SpacingY values
	readln(Disk, RAM);
	Position := 0;
	repeat
		Position := Position + 1;
		until (RAM[Position] = ';') or (RAM[Position] = '.') or (RAM[Position] = ',') or (Position > Length(RAM));
		
	SpacingX := StrToInt(RAM[1..Position - 1]);
	SpacingY := StrToInt(RAM[Position + 1.. Length(RAM)]);
	
	//Read the TileWidth and TileHeight values
	readln(Disk, RAM);
	
	Position := 0;
	repeat
		Position := Position + 1;
		until (RAM[Position] = ';') or (RAM[Position] = '.') or (RAM[Position] = ',') or (Position > Length(RAM));
		
	TileWidth := StrToInt(RAM[1..Position - 1]);
	TileHeight := StrToInt(RAM[Position + 1.. Length(RAM)]);
	
	//Read the TilesPerRow and TilesPerColumn values
	readln(Disk, RAM);
	
	Position := 0;
	repeat
		Position := Position + 1;
		until (RAM[Position] = ';') or (RAM[Position] = '.') or (RAM[Position] = ',') or (Position > Length(RAM));
		
	TilesPerRow := StrToInt(RAM[1..Position - 1]);
	TilesPerColumn := StrToInt(RAM[Position + 1.. Length(RAM)]);
	
	//Read the Tiles value (total number of tiles)
	Readln(Disk, RAM);
	Tiles := StrToInt(RAM);
	
	Close(Disk);
end;

procedure TileSet.SetOffSet(X,Y: Int64);
begin
	OffSetX := X;
	OffSetY := Y;
end;

procedure TileSet.SetSpacing(X,Y: Int64);
begin
	SpacingX := X;
	SpacingY := Y;
end;

procedure TileSet.SetTileSize(X,Y: Int64);
begin
	TileWidth := X;
	TileHeight := Y;
end;

procedure TileSet.Update();
var
	Ypp: Int64;
	Xpp: Int64;
	c: Int64;
	lX, lY: Int64;
	Done: Boolean;
	
begin
	Done := False;
	Tiles := ( (Data.GlWidth - OffsetX) div (TileWidth + SpacingX) ) * ( (Data.GlHeight - OffSetY) div (TileHeight + SpacingY) );
	c := 0;
	Xpp := OffsetX;
	Ypp := OffSetY;
	lY := 1;
	lX := 1;
	repeat
		c := c + 1;
		Tile[c].XPosition := Xpp;
		Tile[c].YPosition := Ypp;
		//writeln('UPD ',c,' = ',Tile[c].XPosition,'x',Tile[c].YPosition);
		Xpp := Xpp + SpacingX + TileWidth;
		lX := lX + 1;
		if (Xpp + TileWidth + SpacingX >= Data.GlWidth) or (lX > TilesPerRow) then
			begin
				Xpp := OffSetX;
				Ypp := Ypp + SpacingY + TileHeight;
				lY := lY + 1;
				lX := 1;
			end;
		if (Ypp + TileHeight + SpacingY >= Data.GlHeight) and (Xpp + TileWidth + SpacingX >= Data.GlWidth) then
			Done := True;
		if c >= Tiles then
			Done := True;
		if (lY > TilesPerColumn) and (lX > TilesPerRow) then
			Done := True;
		until Done = True;
end;

procedure TileSet.Empty();
begin
	Data.Empty();
end;

procedure TileSet.DrawTile(X, Y, TileID: Int64);
begin
	Data.DrawSelection(Tile[TileID].XPosition, Tile[TileID].YPosition, TileWidth, TileHeight, X, Y);
end;
